<?php
/**
 * nssize plugin: Display disk space of a specific namespace
 * 
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author     Ikuo Obataya
 * @version    2008-03-23
 */

if(!defined('DOKU_INC')) define('DOKU_INC',realpath(dirname(__FILE__).'/../../').'/');
require_once(DOKU_INC.'inc/init.php');
if(!defined('DOKU_PLUGIN')) define('DOKU_PLUGIN',DOKU_INC.'lib/plugins/');
require_once(DOKU_PLUGIN.'syntax.php');

class syntax_plugin_nssize extends DokuWiki_Syntax_Plugin {
  function getInfo(){
    return array(
       'author' => 'Ikuo Obataya',
       'email'  => 'I.Obataya@gmail.com',
       'date'   => '2007-3-22',
       'name'   => 'NSSize Plugin',
       'desc'   => 'Display disk space of a specific namespace',
       'url'    => 'http://wiki.symplus.co.jp/computer/en/nssize_plugin',
       );
  }

  function getType(){    return 'substition';  }
  function getSort(){    return 150;  }
  function connectTo($mode) { $this->Lexer->addSpecialPattern('{{nssize>[^}]+}}',$mode,'plugin_nssize'); }
  function handle($match, $state, $pos, &$handler) {
    $subdir = substr($match,9,-2);
    $subdir = str_replace(":","/",$subdir);
    $base = $this->getPwd();
    $base .= "/data/";

    $message.= '<ul class="nssize">';
    $message.= '<li class="nssize_title">'.$subdir.'</li>'.NL;
    $total = 0;

    $pageDir   = $base.'pages/'.$subdir;
    $pageSize  = $this->getSize($pageDir);
    $total    += $pageSize;
    if ($this->getConf('display_pages')){
      $message  .= $this->getFormatted("Pages",$pageSize);
    }
    
    $mediaDir  = $base.'media/'.$subdir;
    $mediaSize = $this->getSize($mediaDir);
    $total    += $mediaSize;
    if ($this->getConf('display_media')==true){
      $message  .= $this->getFormatted("Media",$mediaSize);
    }

    $cacheDir  = $base.'cache/'.$subdir;
    $cacheSize = $this->getSize($cacheDir);
    $total    += $cacheSize;
    if ($this->getConf('display_cache')==true){
      $message  .= $this->getFormatted("Cache",$cacheSize);
    }
    
    $metaDir  = $base.'meta/'.$subdir;
    $metaSize = $this->getSize($metaDir);
    $total   += $metaSize;
    if ($this->getConf('display_meta')==true){
      $message .= $this->getFormatted("Meta",$metaSize);
    }

    $atticDir  = $base.'attic/'.$subdir;
    $atticSize = $this->getSize($atticDir);
    $total    += $atticSize;    
    if ($this->getConf('display_attic')==true){
      $message  .= $this->getFormatted("Attic",$atticSize);
    }
    
    $message .= $this->getFormatted("Sum",$total);
    
    $message .= "</ul>".NL;
    return $message;
  }

  
  function render($mode, &$renderer, $data) {
    if ($mode == 'xhtml') {
      $renderer->doc .= $data.NL;
      return true;
    }
    return false;
  }
  function getPwd(){
    $value = exec("pwd");
    return $value;
  }
  
  function getSize($fullpath){
    $values = explode(" ",exec("du -k ".$fullpath));
    $size = $values[0]/1024;
    return $size;
  }

  function getFormatted($type,$size){
    $dispsize = sprintf("%.2f",$size);
    if ($type!="Sum"){
        return '<li class="nssize_item">'.$type.'</li><li class="nssize_value">'.$dispsize.' MB</li>'.NL;
    }else{
      if ($this->getConf('display_sum')){
        if ($size < $this->getConf('alert_size')){
          return '<li class="nssize_sum_item">'.$type.'</li><li class="nssize_sum_value">'.$dispsize.' MB</li>'.NL;
        }else{
          return '<li class="nssize_sum_alertitem">'.$type.'</li><li class="nssize_sum_alertvalue">'.$dispsize.' MB</li>'.NL;
        }
      }
    }
  }
}

?>